#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
#    Name:	Divide Selected Faces
#      By:	sdmitch
#   Usage:	Plugins>Divide Selected Faces
#	   Note:	enter zero(0) for no divisions along a particular axis
#			
#    Date:	Mar 2011
#------------------------------------------------------------------------------------------------

module SDM
	
	module Divide_Selected_Faces
	
		def self.main
			mod=Sketchup.active_model
			sel=mod.selection
			ent=mod.entities
			if sel.empty?
				UI.messagebox "Nothing selected.  Select at least one face"
			else
				values=UI.inputbox ["X-Segments:","Y-Segments"],[2,2],"Divide Selected Faces"
				if !values then return end
				xseg,yseg=values; xseg=[xseg,1].max; yseg=[yseg,1].max
				faces=sel.grep(Sketchup::Face)
				if faces.length == 0
					UI.messagebox "Select at least 1 face"
					return
				else
					mod.start_operation "Divide Selected Faces"
					for f in faces
						tllc=f.bounds.min; turc=f.bounds.max
						dx=(turc.x-tllc.x)/xseg; dy=(turc.y-tllc.y)/yseg; x,y,z=f.normal.axes
						x.reverse! if z.z < 0
						for i in 1...xseg
							pts=[]; pts.push tllc.offset(x,dx*i)
							for j in 1..yseg
								pts.push pts[-1].offset(y,dy)
							end
							ent.add_edges(pts)
						end
						for i in 1...yseg
							pts=[];pts.push tllc.offset(y,dy*i)
							for j in 1..xseg
								pts.push pts[-1].offset(x,dx)
							end
							ent.add_edges(pts)
						end
					end
				end
				mod.commit_operation
			end
		end
	end
end

if !file_loaded?("Divide Selected Faces.rb")
	UI.menu("Plugins").add_item("Divide Selected Faces") { SDM::Divide_Selected_Faces.main }
	file_loaded("Divide Selected Faces.rb")
end


